@@ -18,7 +18,7 @@ from akerbp.mlops.core import logger
 logging=logger.get_logger(name='gc_helper')
 
 project_id = os.getenv("GOOGLE_PROJECT_ID")
-
+logging.debug(f"{project_id=}")
 
 def create_service_account(service_account):
     """
@@ -45,6 +45,7 @@ def access_secret_version(secret_id, version_id="latest"):
     See https://codelabs.developers.google.com/codelabs/secret-manager-python/index.html?index=..%2F..index#5
     See https://dev.to/googlecloud/serverless-mysteries-with-secret-manager-libraries-on-google-cloud-3a1p
     """
+    logging.debug(f"Read secret {secret_id}")
     from google.cloud import secretmanager
     # Create the Secret Manager client.
     client = secretmanager.SecretManagerServiceClient()
@@ -93,7 +94,8 @@ def run_container(image_name, service_account):
             --region=europe-north1 \
             --no-allow-unauthenticated \
             --memory=512M \
-            --service-account {service_account}",
+            --service-account {service_account} \
+            --set-env-vars=[GOOGLE_PROJECT_ID={project_id}]",
         shell=True
     )
 
